==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hr_HR\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Pozadina"

, "Standard IMAP"
: "Standardni IMAP"

, "Standard SMTP"
: "Standardni SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Poslužitelj"

, "Username"
: "Korisničko ime"

, "Password"
: "Zaporka"

, "Port"
: "Port"

, "Secure Connection"
: "Sigurna konekcija"

, "None"
: "Ništa"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Koristi sistemski račun"

, "No"
: "Ne"

, "Yes"
: "Da"

, "Append domain to login name"
: "Dodaj domenu imenu za prijavu"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus administator"

, "Cyrus Admin Password"
: "Cyrus lozinka administratora"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentikacija"

, "Login"
: "Login"

, "Plain"
: "Jednostavno"

, "Primary Domain"
: "Primarna domena"

, "Secondary Domains (comma separated)"
: "Sekundarna domena (odvojena zarezom)"

, "Notifications service address"
: "Servisna adresa notifikacija"

, "Notification Username"
: "Korisničko ime notifikacija"

, "Notification Password"
: "Zaporka notifikacija"

, "Notifications local client (hostname or IP address)"
: "Obavijesti lokalno klijenta (poslužitelj ili IP adresa)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Korisnik ili UID"

, "Group or GID"
: "Grupa ili GID"

, "Home Template"
: "Početni predložak"

, "Password Scheme"
: "Shema lozinke"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "I have read the license agreement and accept it"
: "Pročitao sam ugovor o korištenju i prihvaćam ga"

, "License Agreement"
: "Ugovor o korištenju"

, "I have read the privacy agreement and accept it"
: "Pročitao sam ugovor o privatnosti i prihvaćam ga"

, "Privacy Agreement"
: "Ugovor o privatnosti"

, "Accept Terms and Conditions"
: "Prihvaćam uvjete korištenja"

, "Performing Environment Checks..."
: "Izvršavam provjere okruženja..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "{0} ne može biti pronađeno. Pokušajte promijeniti svoje filter-kriterije, opcije pregleda ili što traži u {1}. "

, "Check"
: "Provjeri"

, "Result"
: "Rezultat"

, "Error"
: "Greška"

, "Run setup tests"
: "Pokreni testove podešavanja"

, "Ignore setup tests"
: "Ignoriraj testove podešavanja"

, "Install application"
: "Instaliraj aplikaciju"

, "File"
: "Datoteka"

, "Setup Authentication"
: "Podešavanje autentikacije"

, "Database"
: "Baza podataka"

, "User"
: "Korisnik"

, "Prefix"
: "Prefiks"

, "Logging"
: "Logiranje"

, "Filename"
: "Ime datoteke"

, "Priority"
: "Prioritet"

, "Caching"
: "Keširanje"

, "Lifetime (seconds)"
: "Životni vijek (sekunde)"

, "Path"
: "Putanja"

, "Queue"
: "U redu"

, "Session"
: "Sesija"

, "Temporary files"
: "Privremene datoteke"

, "Temporary Files Path"
: "Putanja privremenih datoteka"

, "Filestore directory"
: "Direktorij za spremanje datoteka"

, "Filestore Path"
: "Putanja do direktorija za spremanje datoteka"

, "Addressbook Map panel"
: "Mapa imenika"

, "Map panel"
: "Mapa"

, "disabled"
: "isključeno"

, "enabled"
: "uključeno"

, "Config file is not writable"
: "Upis u konfiguracijsku datoteku nije moguć"

, "Save config"
: "Spremi konfiguraciju"

, "Download config file"
: "Preuzmi konfiguracijsku datoteku"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Uvjeti i odredbe"

, "Setup Checks"
: "Provjere postavki"

, "Config Manager"
: "Uređivač konfiguracije"

, "Authentication/Accounts"
: "Autentikacija/Računi"

, "Email"
: "E-mail"

, "Application Manager"
: "Uređivač aplikacija"

, "Delete all existing users and groups"
: "Izbriši sve postojeće korisnike i grupe"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Prijelaz sa SQL na  LDAP će izbrisati sve postojeće korisničke račune, grupe i uloge. Želite li stvarno zamjeniti pozadinu pohrane računa na LDAP? "

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Inicijalni admin korisnik"

, "Initial admin login name"
: "Inicijalno ime za prijavu admin korisnika"

, "Initial admin Password"
: "Inicijalna admin zaporka"

, "Password confirmation"
: "Potvrda zaporke"

, "Authentication provider"
: "Pružatelj autentikacije"

, "Try to split username"
: "Pokušajte razdvojiti korisničko ime"

, "Account canonical form"
: "Kanonski oblik računa"

, "Account domain name"
: ""

, "Account domain short name"
: "Skraćeno domensko ime računa"

, "Host"
: "Host"

, "Login name"
: "Ime za prijavu"

, "Bind requires DN"
: "Zahtjev vezanja DN"

, "Start TLS"
: ""

, "Base DN"
: "Baza DN"

, "Search filter"
: "Filter pretraživanja"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Pohrana računa"

, "Default user group name"
: "Zadano ime korisničke grupe"

, "Default admin group name"
: "Zadano ime admin grupe"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Postavke Lozinki"

, "User can change password"
: "Korisnik može promijeniti zaporku"

, "Enable password policy"
: "Omogući politiku lozinki"

, "Only ASCII"
: "Samo ASCII"

, "Minimum length"
: "Minimalna duljina"

, "Minimum word chars"
: "Minimalan broj znakova u riječi"

, "Minimum uppercase chars"
: "Minimalan broj velikih slova"

, "Minimum special chars"
: "Minimalan broj spedijalnih znakova"

, "Minimum numbers"
: "Minimalan broj znamenki"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Zabranjen dio u imena u lozinci"

, "Redirect Settings"
: "Preusmjeravanje postavki"

, "Redirect Url (redirect to login screen if empty)"
: "Preusmjeravanje Url (preusmjeriti na zaslon prijave ukoliko je prazan)"

, "Redirect Always (if No, only redirect after logout)"
: "Preusmjeri uvijek (ako ne, preusmjeri samo nakon odjave)"

, "Redirect to referring site, if exists"
: "Preusmjeravanje na web-lokaciju s koje dolazi, ako postoji"

, "Password encoding"
: "Kodiranje zaporke"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Korisnik DN"

, "User Filter"
: "Korisnički filter"

, "User Search Scope"
: "Područje traženja korisnika"

, "Groups DN"
: "Grupa DN"

, "Group Filter"
: "Filter grupe"

, "Group Search Scope"
: "Područje traženja grupe"

, "Use Rfc 2307 bis"
: "Koristi Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minimalan korisnički ID"

, "Max User Id"
: "Maksimalan korisnički ID"

, "Min Group Id"
: "Minimalan ID grupe"

, "Max Group Id"
: "Maksimalan ID grupe"

, "Group UUID Attribute name"
: "Naziv atributa za UUID grupe"

, "User UUID Attribute name"
: "Naziv atributa za UUID korisnika"

, "Readonly access"
: "Pristup samo za čitanja"

, "Save config and install"
: "Spremi i instaliraj konfiguraciju"

, "Passwords don't match"
: "Zaporke nisu jednake"

, "Should not be empty"
: "Ne bi trebalo biti prazno"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplikacija"
 ,"Aplikacije"
 ,"Aplikacija"

]
, "Name"
: "Ime"

, "Enabled"
: "Omogućeno"

, "Order"
: "Poredak"

, "Installed Version"
: "Instalirana verzija"

, "Available Version"
: "Dostupna verzija"

, "Status"
: "Status"

, "Depends on"
: "Ovisi o"

, "Uninstall application"
: "Ukloni aplikaciju"

, "Update application"
: "Ažuriraj aplikaciju"

, "Go to {0} login"
: "Idi na {0} prijavu"

, "uninstall"
: "ukloni"

, "Do you really want to uninstall the application(s)?"
: "Želite li stvarno ukloniti aplikaciju(e)?"

, "This may take a while"
: "Ovo bi moglo potrajati"

, "Dependency Violation"
: "Kršenje ovisnosti"

, "CLI Required"
: ""

, "Application"
: "Aplikacija"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-hr_HR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Pročitao sam ugovor o korištenju i prihvaćam ga"

, "License Agreement"
: "Ugovor o korištenju"

, "I have read the privacy agreement and accept it"
: "Pročitao sam ugovor o privatnosti i prihvaćam ga"

, "Privacy Agreement"
: "Ugovor o privatnosti"

, "Accept Terms and Conditions"
: "Prihvaćam uvjete korištenja"

, "Backend"
: "Pozadina"

, "Standard IMAP"
: "Standardni IMAP"

, "Standard SMTP"
: "Standardni SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Poslužitelj"

, "Username"
: "Korisničko ime"

, "Password"
: "Zaporka"

, "Port"
: "Port"

, "Secure Connection"
: "Sigurna konekcija"

, "None"
: "Ništa"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Koristi sistemski račun"

, "No"
: "Ne"

, "Yes"
: "Da"

, "Append domain to login name"
: "Dodaj domenu imenu za prijavu"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus administator"

, "Cyrus Admin Password"
: "Cyrus lozinka administratora"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentikacija"

, "Login"
: "Login"

, "Plain"
: "Jednostavno"

, "Primary Domain"
: "Primarna domena"

, "Secondary Domains (comma separated)"
: "Sekundarna domena (odvojena zarezom)"

, "Notifications service address"
: "Servisna adresa notifikacija"

, "Notification Username"
: "Korisničko ime notifikacija"

, "Notification Password"
: "Zaporka notifikacija"

, "Notifications local client (hostname or IP address)"
: "Obavijesti lokalno klijenta (poslužitelj ili IP adresa)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Database"

, "MySql User"
: "MySql User"

, "MySql Password"
: "MySql Password"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Korisnik ili UID"

, "Group or GID"
: "Grupa ili GID"

, "Home Template"
: "Početni predložak"

, "Password Scheme"
: "Shema lozinke"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Uvjeti i odredbe"

, "Setup Checks"
: "Provjere postavki"

, "Config Manager"
: "Uređivač konfiguracije"

, "Authentication/Accounts"
: "Autentikacija/Računi"

, "Email"
: "E-mail"

, "Application Manager"
: "Uređivač aplikacija"

, "Setup"
: ""

, "Name"
: "Ime"

, "Enabled"
: "Omogućeno"

, "Order"
: "Poredak"

, "Installed Version"
: "Instalirana verzija"

, "Available Version"
: "Dostupna verzija"

, "Status"
: "Status"

, "Depends on"
: "Ovisi o"

, "Install application"
: "Instaliraj aplikaciju"

, "Uninstall application"
: "Ukloni aplikaciju"

, "Update application"
: "Ažuriraj aplikaciju"

, "Go to {0} login"
: "Idi na {0} prijavu"

, "uninstall"
: "ukloni"

, "Do you really want to uninstall the application(s)?"
: "Želite li stvarno ukloniti aplikaciju(e)?"

, "This may take a while"
: "Ovo bi moglo potrajati"

, "Dependency Violation"
: "Kršenje ovisnosti"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Izbriši sve postojeće korisnike i grupe"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Prijelaz sa SQL na  LDAP će izbrisati sve postojeće korisničke račune, grupe i uloge. Želite li stvarno zamjeniti pozadinu pohrane računa na LDAP? "

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Inicijalni admin korisnik"

, "Initial admin login name"
: "Inicijalno ime za prijavu admin korisnika"

, "Initial admin Password"
: "Inicijalna admin zaporka"

, "Password confirmation"
: "Potvrda zaporke"

, "Authentication provider"
: "Pružatelj autentikacije"

, "Try to split username"
: "Pokušajte razdvojiti korisničko ime"

, "Account canonical form"
: "Kanonski oblik računa"

, "Account domain name"
: ""

, "Account domain short name"
: "Skraćeno domensko ime računa"

, "Host"
: "Host"

, "Login name"
: "Ime za prijavu"

, "Bind requires DN"
: "Zahtjev vezanja DN"

, "Start TLS"
: ""

, "Base DN"
: "Baza DN"

, "Search filter"
: "Filter pretraživanja"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Pohrana računa"

, "Default user group name"
: "Zadano ime korisničke grupe"

, "Default admin group name"
: "Zadano ime admin grupe"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Postavke Lozinki"

, "User can change password"
: "Korisnik može promijeniti zaporku"

, "Enable password policy"
: "Omogući politiku lozinki"

, "Only ASCII"
: "Samo ASCII"

, "Minimum length"
: "Minimalna duljina"

, "Minimum word chars"
: "Minimalan broj znakova u riječi"

, "Minimum uppercase chars"
: "Minimalan broj velikih slova"

, "Minimum special chars"
: "Minimalan broj spedijalnih znakova"

, "Minimum numbers"
: "Minimalan broj znamenki"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Zabranjen dio u imena u lozinci"

, "Redirect Settings"
: "Preusmjeravanje postavki"

, "Redirect Url (redirect to login screen if empty)"
: "Preusmjeravanje Url (preusmjeriti na zaslon prijave ukoliko je prazan)"

, "Redirect Always (if No, only redirect after logout)"
: "Preusmjeri uvijek (ako ne, preusmjeri samo nakon odjave)"

, "Redirect to referring site, if exists"
: "Preusmjeravanje na web-lokaciju s koje dolazi, ako postoji"

, "Password encoding"
: "Kodiranje zaporke"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Korisnik DN"

, "User Filter"
: "Korisnički filter"

, "User Search Scope"
: "Područje traženja korisnika"

, "Groups DN"
: "Grupa DN"

, "Group Filter"
: "Filter grupe"

, "Group Search Scope"
: "Područje traženja grupe"

, "Use Rfc 2307 bis"
: "Koristi Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minimalan korisnički ID"

, "Max User Id"
: "Maksimalan korisnički ID"

, "Min Group Id"
: "Minimalan ID grupe"

, "Max Group Id"
: "Maksimalan ID grupe"

, "Group UUID Attribute name"
: "Naziv atributa za UUID grupe"

, "User UUID Attribute name"
: "Naziv atributa za UUID korisnika"

, "Readonly access"
: "Pristup samo za čitanja"

, "Save config and install"
: "Spremi i instaliraj konfiguraciju"

, "Save config"
: "Spremi konfiguraciju"

, "Passwords don't match"
: "Zaporke nisu jednake"

, "Should not be empty"
: "Ne bi trebalo biti prazno"

, "Performing Environment Checks..."
: "Izvršavam provjere okruženja..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "{0} ne može biti pronađeno. Pokušajte promijeniti svoje filter-kriterije, opcije pregleda ili što traži u {1}. "

, "Check"
: "Provjeri"

, "Result"
: "Rezultat"

, "Error"
: "Greška"

, "Run setup tests"
: "Pokreni testove podešavanja"

, "Ignore setup tests"
: "Ignoriraj testove podešavanja"

, "Application, Applications"
: [
  "Aplikacija"
 ,"Aplikacije"
 ,"Aplikacija"

]
, "File"
: "Datoteka"

, "Setup Authentication"
: "Podešavanje autentikacije"

, "Database"
: "Baza podataka"

, "User"
: "Korisnik"

, "Prefix"
: "Prefiks"

, "Logging"
: "Logiranje"

, "Filename"
: "Ime datoteke"

, "Priority"
: "Prioritet"

, "Caching"
: "Keširanje"

, "Lifetime (seconds)"
: "Životni vijek (sekunde)"

, "Path"
: "Putanja"

, "Queue"
: "U redu"

, "Session"
: "Sesija"

, "Temporary files"
: "Privremene datoteke"

, "Temporary Files Path"
: "Putanja privremenih datoteka"

, "Filestore directory"
: "Direktorij za spremanje datoteka"

, "Filestore Path"
: "Putanja do direktorija za spremanje datoteka"

, "Addressbook Map panel"
: "Mapa imenika"

, "Map panel"
: "Mapa"

, "disabled"
: "isključeno"

, "enabled"
: "uključeno"

, "Config file is not writable"
: "Upis u konfiguracijsku datoteku nije moguć"

, "Download config file"
: "Preuzmi konfiguracijsku datoteku"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplikacija"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
